#!/usr/bin/env python
# _*_ coding:utf-8 _*_

import random
import os, sys
import string
from OCChaos.OCChaosConfig import OCChaosConfig


class OCChaosUselessClassfile(object):
    first = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
    second = "abcdefghijklmnopqrstuvwxyz"
    number = "345"
    index = 0
    array = []

    def __init__(self,config):
        self.config = config
        self.out_put_path = config.getOutput_path()
        pass

    # 第一步:首先生成一个500位的数组 驼峰类型的元素 用作文件名 eg:AsdfdfGsd
    def create_fileName(self, nameCount):

        for i in range(nameCount):
            final = (random.choice(self.first))
            index = random.randint(3, 5)
            for i in range(index):
                final += (random.choice(self.second))
            final += (random.choice(self.first))
            for i in range(index):
                final += (random.choice(self.second))
            self.array.append(final)
        print(self.array)

    # 第二步:
    # 用上边生成的文件名数组来创建对应的.h和.m文件
    # 创建.h文件
    def text_createH(self, fileName, msg, msg1, propertyNumber, methodArray, msg3):

        if not os.path.exists(self.out_put_path + '/'):
            os.mkdir(self.out_put_path + '/')

        full_path = self.out_put_path + '/' + fileName + '.h'
        file = open(full_path, 'w')
        file.write(
            '//\n//  ' + fileName + '.h\n//  Tywin\n\n//  Created by Tywin on 2019.\n//  Copyright ©  2019年 Tywin. All rights reserved.\n//\n\n')
        file.write(msg)
        file.write(msg1)
        propryNameArray = []
        for index in range(1, propertyNumber):
            propryNameArray.append(random.choice(self.array))
        propryNameArray = list(set(propryNameArray))
        for propertyName in propryNameArray:
            file.write('@property(nonatomic,strong)' + random.choice(self.config.getClassArray()) + ' * ' + propertyName + ';\n')
        file.write('\n\n')
        for methodName in methodArray:
            file.write('- (void)pushTo' + methodName + 'VC:(NSDictionary *)info;\n')
        file.write(msg3)
        file.close()
        print(fileName+'.h Done')

    # 创建.m文件
    def text_createM(self, fileNmae, msg, msg1, methodArray, msg3):
        full_path = self.out_put_path + '/' + fileNmae + '.m'
        file = open(full_path, 'w')
        file.write(
            '//\n//  ' + fileNmae + '.m\n//   Tywin\n\n//  Created by Tywin on 2019.\n//  Copyright ©  2019年 Tywin. All rights reserved.\n//\n\n')
        file.write(msg)
        file.write(msg1)
        for methodName in methodArray:
            file.write(
                '- (void)pushTo' + methodName + 'VC:(NSDictionary *)info\n{\n\n  NSMutableArray *array = [NSMutableArray array];\n')
            number = random.randint(3, 10)
            for i in range(1, number):
                file.write('  [array addObject:@"' + random.choice(self.array) + '"];\n')
            file.write('\n}\n\n')
        file.write(msg3)
        file.close()
        print(fileNmae+'.m Done')

    # array = ['HwxrFvrj', 'QnzduQbtdd', 'PvcrwLtqhf', 'UvdhDbjn', 'SuntmyTxvyzg', 'CvlxwBipbp', 'GzrdyzIbimvz', 'CqsjqMmgsp', 'OxaaeuWjhasc', 'NjiardRvwgbi', 'NcculmLtpljq', 'ApoqQrll', 'GkgokDyvjb', 'EblldkVouplj', 'KfdrFvnw', 'SfhyhObftc', 'SmruByoc', 'YzcccvXmpmit', 'OmqvaHpxat', 'XzytsUyvyd', 'MjforNnnyi', 'ZvjhuIdogs', 'BzfrxzSeahxc', 'PycycwFjtpny', 'XvngtoSedljr', 'DktiaCbucd', 'AqbplNuodc', 'MzkvgZuala', 'KdwzIoej', 'AaynatUpqcfd', 'IyvwhZvtjc', 'UmijGmsy', 'AoayndXxghym']
    # array = list(set(array))




    def start_create_files(self,output_path, fileCount=20):
        self.out_put_path = output_path
        self.create_fileName(nameCount=fileCount)  # 随机生成文件名称,数量由外部控制
        for name in self.array:
            number = random.randint(3, 10)
            methodArray = []
            for i in range(1, 5):
                methodArray.append(random.choice(self.array))
            methodArray = list(set(methodArray))  # 数组去重
            self.text_createH(name + 'ViewController', '#import <UIKit/UIKit.h>\n',
                              '@interface ' + name + 'ViewController:' + 'UIViewController\n\n', number, methodArray,
                              '\n\n@end')
            self.text_createM(name + 'ViewController',
                              '#import "' + name + 'ViewController.h"\n\n' '@interface ' + name + 'ViewController()\n\n @end\n\n',
                              '@implementation ' + name + 'ViewController\n\n- (void)viewDidLoad { \n\n [super viewDidLoad];\n\n}\n\n',
                              methodArray, '\n\n@end')


if __name__ == '__main__':
    uselessClass = OCChaosUselessClassfile()
    uselessClass.start_create_files(20)



# -*- coding: utf-8 -*-

import hashlib
import os

from OCChaos.OCChaosConfig import OCChaosConfig


class OCChaosImgMd5Change(object):
    def __init__(self,config):
        self.config = config

    # 获取MD5
    def GetFileMd5(self, filename):
        if not os.path.isfile(filename):
            return
        myhash = hashlib.md5()
        f = open(filename, 'rb')
        while True:
            b = f.read(8096)
            if not b:
                break
            myhash.update(b)
        f.close()
        return myhash.hexdigest()

    # 给文件添加末尾，改变md5
    def fileAppend(self, filename):
        myfile = open(filename, 'a')
        # 添加一个自定义内容，并不影响文件
        myfile.write("jneth")
        myfile.close

    # 遍历文件，符合规则的进行重命名
    # 项目路径   （找到自己的项目路径）
    def start_change_img_md5(self):

        for (root, dirs, files) in os.walk(self.config.getProject_path()):
            for file_name in files:
                if file_name.endswith(self.config.getImg_suf_set()):
                    short_name = os.path.splitext(file_name)[0]
                    realpath = os.path.join(root, file_name)
                    print(short_name + ' ==> ' + realpath)
                    oldMd5 = os.GetFileMd5(realpath)
                    os.fileAppend(realpath)
                    newMd5 = os.GetFileMd5(realpath)
                    print(oldMd5 + '-->' + newMd5)


if __name__ == "__main__":
    md5 = OCChaosImgMd5Change()
    md5.start_change_img_md5()



# -*- coding: utf-8 -*-
import os
from OCChaos.OCChaosConfig import OCChaosConfig


class OCChaosPrefixRe(object):
    def __init__(self,config):
        self.config = config

    # 文件重命名函数，返回新的文件名
    def file_rename(self, file_path):
        root_path = os.path.split(file_path)[0]  # 文件目录
        root_name = os.path.split(file_path)[1]  # 文件名包含扩展名
        filename = os.path.splitext(root_name)[0];  # 文件名
        filetype = os.path.splitext(root_name)[1];  # 文件扩展名

        new_path = os.path.join(root_path,
                                filename.replace(self.config.getPre_str(),
                                                 self.config.getPre_to_str()) + filetype)  # 拼接新路径
        os.renames(file_path, new_path)  # 文件重命名
        return filename.replace(self.config.getPre_str(), self.config.getPre_to_str())

    def start_rename(self):
        # 定义一个字典 key=旧类名 value=新类名
        needModifyDic = {}

        # 遍历文件，符合规则的进行重命名
        for (root, dirs, files) in os.walk(self.config.getProject_path()):
            for file_name in files:
                if file_name.startswith((self.config.getPre_str(),)) and file_name.endswith(self.config.getSuf_set()):
                    old_name = os.path.splitext(file_name)[0]
                    new_name = self.file_rename(os.path.join(root, file_name))
                    needModifyDic[old_name] = new_name

        # 遍历文件，在文件中更换新类名的引用
        print(needModifyDic)
        for (root, dirs, files) in os.walk(self.config.getProject_path()):
            for file_name in files:
                if file_name.endswith(self.config.getSuf_set()):
                    print('-----fileName-------' + file_name)
                    with open(os.path.join(root, file_name), 'r+') as f:
                        print('========fileName========' + file_name)
                        s0 = f.read()
                        f.close()
                        for key in needModifyDic:
                            if key in s0:
                                with open(os.path.join(root, file_name), 'r+') as f4:
                                    s1 = f4.read().replace(key, needModifyDic[key])
                                    print(key + ' ------> ' + needModifyDic[key])
                                    f4.seek(0)
                                    f4.write(s1)
                                    f4.truncate()
                                    f4.close()
        # 替换配置文件中的类名
        for key in needModifyDic:
            with open(self.config.getPbxpro_path(), 'r+') as f:
                s0 = f.read()
                f.close()
                if key in s0:
                    with open(self.config.getPbxpro_path(), 'r+') as f2:
                        s = f2.read().replace(key, needModifyDic[key])
                        f2.seek(0)
                        f2.write(s)
                        f2.truncate()
                        f2.close()



# -*- coding:utf-8 -*-

import json

import OCChaos.Chaos

# keys=["pre_str","pre_to_str","suf_set","project_path","pbxpro_path","img_suf_set","file_floadPath","classArray","h_file_mark_arr","m_file_mark_arr"]
#
# def check_file():
#     print("请输入配置文件路径(请严格按照配置示例进行配置):")
#     file_check_flag = True
#     config_path = input()
#     if config_path.endswith(".json"):
#         with open(config_path, 'r') as f:
#             temp = json.loads(f.read())
#             for k in keys:
#                 if k not in temp:
#                     print(k+"键值不存在或者错误,请检查配置文件\n")
#                     file_check_flag = False
#
#         if file_check_flag:
#             return config_path,os.path.exists(config_path)
#         else:
#             check_file()
#     else:
#         print("需要输入正确的配置文件路径！")
#         check_file()
#
# def select_funtion(config_path:str):
#
#     print("请选择要执行的功能:\n1.更换文件前缀;\n2.生成无用的.h .m文件;\n3.更改资源图片的md5值;\n4.已有.h .m添加废弃代码\n\n请输入序号，按回车")
#     chaos = OCChaos(path=config_path)
#     cmd_str = input()
#     if cmd_str is "1":
#         print("更换文件前缀")
#
#         chaos.changePrefixCallBack()
#     elif cmd_str is "2":
#         print("生成无用的.h .m文件")
#         chaos.createUselessClassCallBack()
#     elif cmd_str is "3":
#         print("更改资源图片的md5值")
#         chaos.changeMd5CallBack()
#     elif cmd_str is "4":
#         print("已有.h .m添加废弃代码")
#         chaos.insertUselessCodeCallBack()
#     else:
#         print("请输入正确序号！")
#         start_action()
#
# def start_action():
#
#     config_path,file_check_result = check_file()
#     if file_check_result == False:
#         check_file()
#         return
#     while True:
#         select_funtion(config_path)

# if __name__ == '__main__':
#     OCChaos.Chaos.start_action()


# -*- coding: utf-8 -*-

import random

import os

from OCChaos.OCChaosConfig import OCChaosConfig


class OCChaosUselessCode(object):
    second = "abcdefghijklmnopqrstuvwxyz"

    first = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"

    third = "1234567890"

    number = "345"

    index = 0

    viewArray = ['UILabel', 'UIScrollView', 'UIView', 'UITextView', 'UITableView',
                 'UIImageView']  # .m文件里创建的元素的类型从这个数组里随机选
    name_array = []

    def __init__(self,config):
        self.config = config

    def getNameArray(self):
        for i in range(500):

            final = (random.choice(self.first))

            index = random.randint(3, 5)

            for i in range(index):
                final += (random.choice(self.first))

            final += (random.choice(self.second))

            for i in range(index):
                final += (random.choice(self.third))

            self.name_array.append(final)

    # .h文件添加废代码

    def HFileAddMj(self, file_path, old_str_arr):
        file_data = ""

        Ropen = open(file_path, 'r')

        for line in Ropen:

            nameStr = random.choice(self.name_array)

            className = random.choice(self.config.getClassArray())

            for old_str in old_str_arr:

                if old_str in line:
                    line += '\n\n/*********FQ代码**********/\n' \
                            '@property(nonatomic,strong) ' + className + ' * ' + nameStr + ';' + \
                            '\n/*********FQ代码**********/\n\n'
                    self.name_array.remove(nameStr)  # 防止创建的属性名重复(创建一个从数组中删除一个)
                    break;

            file_data += line

        Ropen.close()

        Wopen = open(file_path, 'w')

        Wopen.write(file_data)

        Wopen.close()

        print(file_data)

    # .m文件添加废代码

    def MFileAddMj(self, file_path, old_str_arr):
        file_data = ""

        Ropen = open(file_path, 'r')  # 读取文件

        for line in Ropen:

            nameStr = random.choice(self.name_array)

            className = random.choice(self.viewArray)

            for old_str in old_str_arr:

                if old_str in line:  # 如果.h文件中的某一行里包含old_str,则往这一行添加一下语句

                    line += '\n\n\t/*********FQ代码**********/\n\t' \
                            + className + ' * ' + nameStr + ' = ' + '[[' + className + ' alloc]initWithFrame:CGRectMake(' + str(
                        random.randint(0, 100)) + ',' + str(random.randint(0, 100)) + ',' + str(
                        random.randint(0, 100)) + ',' + str(
                        random.randint(0, 100)) + ')];\n' + \
                            '\t' + nameStr + '.layer.cornerRadius =' + str(random.randint(5, 10)) + ';\n\t' \
                            + nameStr + '.userInteractionEnabled = YES;\n\t' \
                            + nameStr + '.layer.masksToBounds = YES;' + \
                            '\n\t/*********FQ代码**********/\n\n'

                    # file_data += line

                    self.name_array.remove(nameStr)  # 防止创建的元素名重复(创建一个从数组中删除一个)
                    break;
            file_data += line

        Ropen.close()

        Wopen = open(file_path, 'w')

        Wopen.write(file_data)

        Wopen.close()

        print(file_data)

    def file_name(self, file_dir):
        for root, dirs, files in os.walk(file_dir):

            # print(root) #当前目录路径

            # print(dirs) #当前路径下所有子目录

            print(files)  # 当前路径下所有非目录子文件

            fileNameArray = files

            # 遍历文件夹下的.h和.m文件并添加废代码

            for file in fileNameArray:

                if '.h' in file:  # file_dir+'/'+file含义是file_dir文件夹下的file文件

                    self.HFileAddMj(file_dir + '/' + file, self.config.getH_file_mark_arr())

                if '.m' in file:
                    self.MFileAddMj(file_dir + '/' + file, self.config.getM_file_mark_arr())

    def start_create_useless_code(self,file_load_path):
        self.getNameArray()
        # 要修改的文件所在的文件夹路径
        self.file_name(file_load_path)


if __name__ == "__main__":
    useless_code = OCChaosUselessCode()
    useless_code.start_create_useless_code()



# -*- coding: utf-8 -*-

from OCChaos.OCChaosImgMd5Change import OCChaosImgMd5Change
from OCChaos.OCChaosPrefixRe import OCChaosPrefixRe
from OCChaos.OCChaosUselessClassfile import OCChaosUselessClassfile
from OCChaos.OCChaosUselessCode import OCChaosUselessCode
from OCChaos.OCChaosConfig import OCChaosConfig


import json
import os,sys

keys=["pre_str","pre_to_str","suf_set","project_path","pbxpro_path","img_suf_set","file_floadPath","classArray","h_file_mark_arr","m_file_mark_arr","output_path"]

class OCChaos(object):

    def __init__(self,path=sys.path[0]+"/config.json"):
        self.path_config = OCChaosConfig(path=path)
        pass


    def changePrefixCallBack(self):
        pre = self.path_config.getPre_str()
        pre_to = self.path_config.getPre_to_str()
        if len(pre_to) == 0  and len(pre) == 0:
            print("类名旧前缀与新前缀没有设置")
            return
        OCChaosPrefixRe(config=self.path_config).start_rename()
        # print(self.path_config.get())

    def changeMd5CallBack(self):
        project_path = self.path_config.getProject_path()
        img_suf = self.path_config.getImg_suf_set()
        if len(project_path) == 0 or len(img_suf) == 0:
            print("工程路径与图片文件后缀没有设置")
            return
        OCChaosImgMd5Change(config=self.path_config).start_change_img_md5()

    def createUselessClassCallBack(self):
        project_path = self.path_config.getProject_path()
        output_path = self.path_config.getOutput_path()
        if len(project_path) == 0 or len(output_path) == 0:
            print("工程路径与输出路径没有设置")
            return
        OCChaosUselessClassfile(config=self.path_config).start_create_files(fileCount=20,output_path=output_path)

    def insertUselessCodeCallBack(self):
        project_path = self.path_config.getProject_path()
        if len(project_path)==0:
            print("工程路径没有设置")
            return
        OCChaosUselessCode(config=self.path_config).start_create_useless_code(project_path)


def check_file():
    print("请输入配置文件路径(请严格按照配置示例进行配置):")
    file_check_flag = True
    config_path = input()

    if len(config_path.replace(" ","")) == 0:
        print("需要输入正确的配置文件路径！")
        return(check_file())
    else:
        if config_path.endswith(".json"):
            with open(config_path, 'r') as f:
                temp = json.loads(f.read())
                print("读取json")
                for k in keys:
                    if k not in temp:
                        print(k+"键值不存在或者错误,请检查配置文件\n")
                        file_check_flag = False
                print("读取json校验完成")
                if file_check_flag:

                    return config_path,os.path.exists(config_path)
                else:
                    return(check_file())#python中递归调用 要使用return
        else:
            print("需要输入正确的配置文件路径！")
            return(check_file())


def select_funtion(config_path):

    print("请选择要执行的功能:\n1.更换文件前缀;\n2.生成无用的.h .m文件;\n3.更改资源图片的md5值;\n4.已有.h .m添加废弃代码\n\n请输入序号，按回车")

    cmd_str = input()
    if cmd_str is "1":
        print("更换文件前缀")
        OCChaos(path=config_path).changePrefixCallBack()
    elif cmd_str is "2":
        print("生成无用的.h .m文件")
        OCChaos(path=config_path).createUselessClassCallBack()
    elif cmd_str is "3":
        print("更改资源图片的md5值")
        OCChaos(path=config_path).changeMd5CallBack()
    elif cmd_str is "4":
        print("已有.h .m添加废弃代码")
        OCChaos(path=config_path).insertUselessCodeCallBack()
    else:
        print("请输入正确序号！")
        select_funtion()

def start_action():

    config_path,file_check_result = check_file()

    if file_check_result:
        while True:
            select_funtion(config_path)


if __name__ == '__main__':
    start_action()


# -*- coding: utf-8 -*-

import json
import os,sys

class OCChaosConfig(object):

    def __init__(self,path):
        self.jsonData = self.get_json_data(path)

    def getPre_str(self):
        return self.jsonData['pre_str']

    def getPre_to_str(self):
        return self.jsonData['pre_to_str']

    def getSuf_set(self):
        return tuple(self.jsonData['suf_set'])

    def getProject_path(self):
        return self.jsonData['project_path']

    def getPbxpro_path(self):
        return self.jsonData['pbxpro_path']

    def getImg_suf_set(self):
        return tuple(self.jsonData['img_suf_set'])

    def getFile_floadPath(self):
        return self.jsonData['file_floadPath']

    def getClassArray(self):
        return self.jsonData['classArray']

    def getH_file_mark_arr(self):
        return self.jsonData['h_file_mark_arr']

    def getM_file_mark_arr(self):
        return self.jsonData['m_file_mark_arr']

    def getOutput_path(self):
        return self.jsonData['output_path']

    def get_json_data(self,path=sys.path[0]+"/config.json"):
        with open(path, 'r') as f:
            temp = json.loads(f.read())
            return temp


# if __name__ == "__main__":
#
#     config = OCChaos_Config()
#     print(config.getImg_suf_set())

'''
一些参数的说明
#需要修改的类名前缀 （需替换）
pre_str = 'ZTY'
# 新的类名前缀 （需替换）
pre_to_str = 'TY'
# 搜寻以下文件类型 （根据自己需求替换）
suf_set = ('.h', '.m', '.xib', '.storyboard', '.mm')
# 项目路径   （找到自己的项目路径）
project_path = '/Volumes/Files/Document/LionMobi/TestIpa/TestIpa'
# 项目project.pbxproj文件路径 需要更新配置文件中的类名 （找到自己的项目project.pbxproj路径）
pbxpro_path = '/Volumes/Files/Document/LionMobi/TestIpa/TestIpa.xcodeproj/project.pbxproj'

# 设置以这些结尾的
img_suf_set = ('.png', '.jpg')

# 在目标.h  .m 文件所在的路径
file_floadPath = '/Volumes/Files/Document/LionMobi/TestIpa/TestIpa'

# .h文件里属性的类型从这个数组里随机选(按需修改)
classArray = ['NSString', 'UILabel', 'NSDictionary', 'NSData', 'UIScrollView', 'UIView', 'UITextView', 'UITableView',
              'UIImageView']

# .h   .m  文件中 需要在哪种标识后面添加废弃代码(按需修改)
h_file_mark_arr = ["l;", "m;", "n;", "q;", "y;"] # 往凡是以"l;", "m;","n;","q;","y;"这些中的某一个结尾的oc语句后添加废弃代码
m_file_mark_arr = ["n];", "w];", "m];", "c];", "p];", "q];", "l];"] # 往凡是以"n];", "w];","m];","c];","p];","q];","l];"这些中的某一个结尾的oc语句后添加废弃代码
'''




#-*- encoding: UTF-8 -*-
from setuptools import setup, find_packages
"""
打包的用的setup必须引入，
"""

VERSION = '1.0.6'

packages = find_packages('OCChaos'),  # 包含所有src中的包
package_dir = {'':'OCChaos'},   # 告诉distutils包都在src下

setup(name='occhaos',
      version=VERSION,
      description="iOS中  OC马甲包制作中，前缀、后缀、垃圾代码生成、加入垃圾代码方案",
      long_description='iOS中  OC马甲包制作中，前缀、后缀、垃圾代码生成、加入垃圾代码方案',
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='iOS 马甲包 垃圾代码 混淆',
      author='tywin',
      author_email='tywinzhang2017@gmail.com',
      url='https://github.com/ilioner/OCChaos',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=True,
      entry_points={
        'console_scripts':[
            'occhaos = OCChaos.Chaos:start_action'
        ]
      }
)


# -*- coding: utf-8 -*-

import logging
from logging import handlers

class Logger(object):
    level_relations = {
        'debug':logging.DEBUG,
        'info':logging.INFO,
        'warning':logging.WARNING,
        'error':logging.ERROR,
        'crit':logging.CRITICAL
    }#日志级别关系映射

    def __init__(self,filename,level='info',when='D',backCount=3,fmt='%(asctime)s - %(pathname)s[line:%(lineno)d] - %(levelname)s: %(message)s'):
        self.logger = logging.getLogger(filename)
        format_str = logging.Formatter(fmt)#设置日志格式
        self.logger.setLevel(self.level_relations.get(level))#设置日志级别
        sh = logging.StreamHandler()#往屏幕上输出
        sh.setFormatter(format_str) #设置屏幕上显示的格式
        th = handlers.TimedRotatingFileHandler(filename=filename,when=when,backupCount=backCount,encoding='utf-8')#往文件里写入#指定间隔时间自动生成文件的处理器
        #实例化TimedRotatingFileHandler
        #interval是时间间隔，backupCount是备份文件的个数，如果超过这个个数，就会自动删除，when是间隔的时间单位，单位有以下几种：
        # S 秒
        # M 分
        # H 小时、
        # D 天、
        # W 每星期（interval==0时代表星期一）
        # midnight 每天凌晨
        th.setFormatter(format_str)#设置文件里写入的格式
        self.logger.addHandler(sh) #把对象加到logger里
        self.logger.addHandler(th)
if __name__ == '__main__':
    log = Logger('all.log',level='debug')
    log.logger.debug('debug')
    log.logger.info('info')
    log.logger.warning('警告')
    log.logger.error('报错')
    log.logger.critical('严重')
    Logger('error.log', level='error').logger.error('error')